==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/DistributionDefaultCacheBehaviorForwardedValuesCookiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.DistributionDefaultCacheBehaviorForwardedValuesCookiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property forward Whether you want CloudFront to forward cookies to the origin that is associated with this cache behavior. You can specify `all`, `none` or `whitelist`. If `whitelist`, you must include the subsequent `whitelisted_names`.
 * @property whitelistedNames If you have specified `whitelist` to `forward`, the whitelisted cookies that you want CloudFront to forward to your origin.
 */
public data class DistributionDefaultCacheBehaviorForwardedValuesCookiesArgs(
    public val forward: Output<String>,
    public val whitelistedNames: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.DistributionDefaultCacheBehaviorForwardedValuesCookiesArgs> {
    override fun toJava():
        com.pulumi.aws.cloudfront.inputs.DistributionDefaultCacheBehaviorForwardedValuesCookiesArgs =
        com.pulumi.aws.cloudfront.inputs.DistributionDefaultCacheBehaviorForwardedValuesCookiesArgs.builder()
            .forward(forward.applyValue({ args0 -> args0 }))
            .whitelistedNames(whitelistedNames?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [DistributionDefaultCacheBehaviorForwardedValuesCookiesArgs].
 */
@PulumiTagMarker
public class DistributionDefaultCacheBehaviorForwardedValuesCookiesArgsBuilder internal
constructor() {
    private var forward: Output<String>? = null

    private var whitelistedNames: Output<List<String>>? = null

    /**
     * @param value Whether you want CloudFront to forward cookies to the origin that is associated with this cache behavior. You can specify `all`, `none` or `whitelist`. If `whitelist`, you must include the subsequent `whitelisted_names`.
     */
    @JvmName("cksyjruqosrhahue")
    public suspend fun forward(`value`: Output<String>) {
        this.forward = value
    }

    /**
     * @param value If you have specified `whitelist` to `forward`, the whitelisted cookies that you want CloudFront to forward to your origin.
     */
    @JvmName("iercfhfknfhjftuw")
    public suspend fun whitelistedNames(`value`: Output<List<String>>) {
        this.whitelistedNames = value
    }

    @JvmName("lmhykrhlsychnsoq")
    public suspend fun whitelistedNames(vararg values: Output<String>) {
        this.whitelistedNames = Output.all(values.asList())
    }

    /**
     * @param values If you have specified `whitelist` to `forward`, the whitelisted cookies that you want CloudFront to forward to your origin.
     */
    @JvmName("jqomawbiwvfdcxnn")
    public suspend fun whitelistedNames(values: List<Output<String>>) {
        this.whitelistedNames = Output.all(values)
    }

    /**
     * @param value Whether you want CloudFront to forward cookies to the origin that is associated with this cache behavior. You can specify `all`, `none` or `whitelist`. If `whitelist`, you must include the subsequent `whitelisted_names`.
     */
    @JvmName("xhbhmelaexiwmqll")
    public suspend fun forward(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.forward = mapped
    }

    /**
     * @param value If you have specified `whitelist` to `forward`, the whitelisted cookies that you want CloudFront to forward to your origin.
     */
    @JvmName("xbavvdliwygojbbd")
    public suspend fun whitelistedNames(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.whitelistedNames = mapped
    }

    /**
     * @param values If you have specified `whitelist` to `forward`, the whitelisted cookies that you want CloudFront to forward to your origin.
     */
    @JvmName("gmclrimildedxikr")
    public suspend fun whitelistedNames(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.whitelistedNames = mapped
    }

    internal fun build(): DistributionDefaultCacheBehaviorForwardedValuesCookiesArgs =
        DistributionDefaultCacheBehaviorForwardedValuesCookiesArgs(
            forward = forward ?: throw PulumiNullFieldException("forward"),
            whitelistedNames = whitelistedNames,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/DistributionDefaultCacheBehaviorForwardedValuesCookiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.DistributionDefaultCacheBehaviorForwardedValuesCookiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property forward Whether you want CloudFront to forward cookies to the origin that is associated with this cache behavior. You can specify `all`, `none` or `whitelist`. If `whitelist`, you must include the subsequent `whitelisted_names`.
 * @property whitelistedNames If you have specified `whitelist` to `forward`, the whitelisted cookies that you want CloudFront to forward to your origin.
 */
public data class DistributionDefaultCacheBehaviorForwardedValuesCookiesArgs(
    public val forward: Output<String>,
    public val whitelistedNames: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.DistributionDefaultCacheBehaviorForwardedValuesCookiesArgs> {
    override fun toJava(): com.pulumi.aws.cloudfront.inputs.DistributionDefaultCacheBehaviorForwardedValuesCookiesArgs =
        com.pulumi.aws.cloudfront.inputs.DistributionDefaultCacheBehaviorForwardedValuesCookiesArgs.builder()
            .forward(forward.applyValue({ args0 -> args0 }))
            .whitelistedNames(whitelistedNames?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [DistributionDefaultCacheBehaviorForwardedValuesCookiesArgs].
 */
@PulumiTagMarker
public class DistributionDefaultCacheBehaviorForwardedValuesCookiesArgsBuilder internal constructor() {
    private var forward: Output<String>? = null

    private var whitelistedNames: Output<List<String>>? = null

    /**
     * @param value Whether you want CloudFront to forward cookies to the origin that is associated with this cache behavior. You can specify `all`, `none` or `whitelist`. If `whitelist`, you must include the subsequent `whitelisted_names`.
     */
    @JvmName("huuqmfjlbwvhdtok")
    public suspend fun forward(`value`: Output<String>) {
        this.forward = value
    }

    /**
     * @param value If you have specified `whitelist` to `forward`, the whitelisted cookies that you want CloudFront to forward to your origin.
     */
    @JvmName("nrpjongssoqjtyxu")
    public suspend fun whitelistedNames(`value`: Output<List<String>>) {
        this.whitelistedNames = value
    }

    @JvmName("gbaqeqrnaklidfrd")
    public suspend fun whitelistedNames(vararg values: Output<String>) {
        this.whitelistedNames = Output.all(values.asList())
    }

    /**
     * @param values If you have specified `whitelist` to `forward`, the whitelisted cookies that you want CloudFront to forward to your origin.
     */
    @JvmName("bdtjsbufgqmrhbcf")
    public suspend fun whitelistedNames(values: List<Output<String>>) {
        this.whitelistedNames = Output.all(values)
    }

    /**
     * @param value Whether you want CloudFront to forward cookies to the origin that is associated with this cache behavior. You can specify `all`, `none` or `whitelist`. If `whitelist`, you must include the subsequent `whitelisted_names`.
     */
    @JvmName("lgioesigorphpumx")
    public suspend fun forward(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.forward = mapped
    }

    /**
     * @param value If you have specified `whitelist` to `forward`, the whitelisted cookies that you want CloudFront to forward to your origin.
     */
    @JvmName("otlsbgisjuguodty")
    public suspend fun whitelistedNames(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.whitelistedNames = mapped
    }

    /**
     * @param values If you have specified `whitelist` to `forward`, the whitelisted cookies that you want CloudFront to forward to your origin.
     */
    @JvmName("bfbcwoexmvrgiqcr")
    public suspend fun whitelistedNames(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.whitelistedNames = mapped
    }

    internal fun build(): DistributionDefaultCacheBehaviorForwardedValuesCookiesArgs =
        DistributionDefaultCacheBehaviorForwardedValuesCookiesArgs(
            forward = forward ?: throw PulumiNullFieldException("forward"),
            whitelistedNames = whitelistedNames,
        )
}
